@@ -23,6 +23,6 @@
 
 from mathjspy.mathjs import MathJS
 
-__author__ = 'Adam morris'
+__author__ = 'Adam Morris'
 
-__version__ = '0.0.4'  # major.minor.patch
\ No newline at end of file
+__version__ = '0.0.5'  # major.minor.patch
\ No newline at end of file
